from sample import Sample
from midi import Midi
import gettext

localedir = './locales'

translate = gettext.translation('base', localedir, fallback=True)
_ = translate.gettext

class SoundGroup:
    def __init__(self, name):
        self.Name = name
        self.DurationText = ""
        self.DurationMultipliers = [2.0, 1.0, 0.66, 0.5]
        self.Sounds = []


class SoundGroups:
    def __init__(self):
        self.SampleSoundGroups = {}
        self.PuzzlesSoundGroups = {}
        self.MidiSoundGroups = {}
        self.InitializeDefaultSoundGroups()

    def GetSoundGroupWithName(self, name):
        if (name in self.SampleSoundGroups):
            return self.SampleSoundGroups[name]
        elif (name in self.PuzzlesSoundGroups):
            return self.PuzzlesSoundGroups[name]
        else:
            return self.MidiSoundGroups[name]

    def InitializeDefaultSoundGroups(self):
        self.InitializeMidiSoundGroups()
        self.InitializeSampleSoundGroups()
        self.InitializePuzzlesSoundGroups();

    def InitializeMidiSoundGroups(self):
        newSG = SoundGroup("Bagpipes")
        newSG.Sounds.append(Midi(_("C5"), "Bagpipes", "/bagpipes/C5.wav"))
        newSG.Sounds.append(Midi(_("D5"), "Bagpipes", "/bagpipes/D5.wav"))
        newSG.Sounds.append(Midi(_("E5"), "Bagpipes", "/bagpipes/E5.wav"))
        newSG.Sounds.append(Midi(_("F5"), "Bagpipes", "/bagpipes/F5.wav"))
        newSG.Sounds.append(Midi(_("G5"), "Bagpipes", "/bagpipes/G5.wav"))
        newSG.Sounds.append(Midi(_("A5"), "Bagpipes", "/bagpipes/A5.wav"))
        newSG.Sounds.append(Midi(_("B5"), "Bagpipes", "/bagpipes/B5.wav"))
        newSG.Sounds.append(Midi(_("C6"), "Bagpipes", "/bagpipes/C6.wav"))
        self.MidiSoundGroups["Bagpipes"] = newSG

        newSG = SoundGroup("Calliope Leads")
        newSG.Sounds.append(Midi(_("C5"), "Calliope Leads", "/calliope/C5.wav"))
        newSG.Sounds.append(Midi(_("D5"), "Calliope Leads", "/calliope/D5.wav"))
        newSG.Sounds.append(Midi(_("E5"), "Calliope Leads", "/calliope/E5.wav"))
        newSG.Sounds.append(Midi(_("F5"), "Calliope Leads", "/calliope/F5.wav"))
        newSG.Sounds.append(Midi(_("G5"), "Calliope Leads", "/calliope/G5.wav"))
        newSG.Sounds.append(Midi(_("A5"), "Calliope Leads", "/calliope/A5.wav"))
        newSG.Sounds.append(Midi(_("B5"), "Calliope Leads", "/calliope/B5.wav"))
        newSG.Sounds.append(Midi(_("C6"), "Calliope Leads", "/calliope/C6.wav"))
        self.MidiSoundGroups["Calliope Leads"] = newSG

        newSG = SoundGroup("Choir Ahhs")
        newSG.Sounds.append(Midi(_("C5"), "Choir Ahhs", "/choir/C5.wav"))
        newSG.Sounds.append(Midi(_("D5"), "Choir Ahhs", "/choir/D5.wav"))
        newSG.Sounds.append(Midi(_("E5"), "Choir Ahhs", "/choir/E5.wav"))
        newSG.Sounds.append(Midi(_("F5"), "Choir Ahhs", "/choir/F5.wav"))
        newSG.Sounds.append(Midi(_("G5"), "Choir Ahhs", "/choir/G5.wav"))
        newSG.Sounds.append(Midi(_("A5"), "Choir Ahhs", "/choir/A5.wav"))
        newSG.Sounds.append(Midi(_("B5"), "Choir Ahhs", "/choir/B5.wav"))
        newSG.Sounds.append(Midi(_("C6"), "Choir Ahhs", "/choir/C6.wav"))
        self.MidiSoundGroups["Choir Ahhs"] = newSG

        newSG = SoundGroup("Piano")
        newSG.Sounds.append(Midi(_("C5"), "Piano", "/piano/C5.wav"))
        newSG.Sounds.append(Midi(_("D5"), "Piano", "/piano/D5.wav"))
        newSG.Sounds.append(Midi(_("E5"), "Piano", "/piano/E5.wav"))
        newSG.Sounds.append(Midi(_("F5"), "Piano", "/piano/F5.wav"))
        newSG.Sounds.append(Midi(_("G5"), "Piano", "/piano/G5.wav"))
        newSG.Sounds.append(Midi(_("A5"), "piano", "/piano/A5.wav"))
        newSG.Sounds.append(Midi(_("B5"), "Piano", "/piano/B5.wav"))
        newSG.Sounds.append(Midi(_("C6"), "Piano", "/piano/C6.wav"))
        self.MidiSoundGroups["Piano"] = newSG

        newSG = SoundGroup("Square Lead")
        newSG.Sounds.append(Midi(_("C5"), "Square Lead", "/squarelead/C5.wav"))
        newSG.Sounds.append(Midi(_("D5"), "Square Lead", "/squarelead/D5.wav"))
        newSG.Sounds.append(Midi(_("E5"), "Square Lead", "/squarelead/E5.wav"))
        newSG.Sounds.append(Midi(_("F5"), "Square Lead", "/squarelead/F5.wav"))
        newSG.Sounds.append(Midi(_("G5"), "Square Lead", "/squarelead/G5.wav"))
        newSG.Sounds.append(Midi(_("A5"), "Square Lead", "/squarelead/A5.wav"))
        newSG.Sounds.append(Midi(_("B5"), "Square Lead", "/squarelead/B5.wav"))
        newSG.Sounds.append(Midi(_("C6"), "Square Lead", "/squarelead/C6.wav"))
        self.MidiSoundGroups["Square Lead"] = newSG

        newSG = SoundGroup("Violin")
        newSG.Sounds.append(Midi(_("C5"), "Violin", "/violin/C5.wav"))
        newSG.Sounds.append(Midi(_("D5"), "Violin", "/violin/D5.wav"))
        newSG.Sounds.append(Midi(_("E5"), "Violin", "/violin/E5.wav"))
        newSG.Sounds.append(Midi(_("F5"), "Violin", "/violin/F5.wav"))
        newSG.Sounds.append(Midi(_("G5"), "Violin", "/violin/G5.wav"))
        newSG.Sounds.append(Midi(_("A5"), "Violin", "/violin/A5.wav"))
        newSG.Sounds.append(Midi(_("B5"), "Violin", "/violin/B5.wav"))
        newSG.Sounds.append(Midi(_("C6"), "Violin", "/violin/C6.wav"))
        self.MidiSoundGroups["Violin"] = newSG

    def InitializeSampleSoundGroups(self):
        newSG = SoundGroup("Animals")
        newSG.Sounds.append(Sample(_("Horse"), 2.71, "/animals/horse.wav"))
        newSG.Sounds.append(Sample(_("Pig"), 6.6, "/animals/pig.wav"))
        newSG.Sounds.append(Sample(_("Rooster"), 1.93, "/animals/rooster.wav"))
        newSG.Sounds.append(Sample(_("Sheep"), 1.7, "/animals/sheep.wav"))
        newSG.Sounds.append(Sample(_("Lion"), 4.75, "/animals/lion.wav"))
        newSG.Sounds.append(Sample(_("Cat"), 4.75, "/animals/cat.wav"))
        newSG.Sounds.append(Sample(_("Dog"), 4.75, "/animals/dog.wav"))
        newSG.Sounds.append(Sample(_("Duck"), 2.25, "/animals/duck.wav"))
        self.SampleSoundGroups["Animals"] = newSG

        newSG = SoundGroup("Beethovens Fifth")
        newSG.Sounds.append(Sample(_("Da Da Da DUM"), 3, "/beethoven/Beet1.wav"))
        newSG.Sounds.append(Sample(_("Da Da Da DOH"), 2.69, "/beethoven/Beet2.wav"))
        newSG.Sounds.append(Sample(_("Te Te Te TOH"), 1.52, "/beethoven/Beet3.wav"))
        newSG.Sounds.append(Sample(_("flum"), 1.11, "/beethoven/Beet4.wav"))
        newSG.Sounds.append(Sample(_("FLAH"), 1.41, "/beethoven/Beet5.wav"))
        self.SampleSoundGroups["Beethovens Fifth"]=newSG


        newSG = SoundGroup("Cowboy Country")
        newSG.Sounds.append(Sample(_("Piano 1"), 1.32, "/cowboy/Chord1.wav"))
        newSG.Sounds.append(Sample(_("Piano 2"), 1.04, "/cowboy/Chord2.wav"))
        newSG.Sounds.append(Sample(_("Piano 3"), 1.76, "/cowboy/Chord3.wav"))
        newSG.Sounds.append(Sample(_("Saloon Door"), 2.99, "/cowboy/SaloonDoor.wav"))
        newSG.Sounds.append(Sample(_("Horse Gallop"), 6.42, "/cowboy/Horse1.wav"))
        newSG.Sounds.append(Sample(_("Horse Neigh"), 2.08, "/cowboy/Horse2.wav"))
        newSG.Sounds.append(Sample(_("Yeehaw Female"), 1.33, "/cowboy/Yehaw1.wav"))
        newSG.Sounds.append(Sample(_("Yeehaw Male"), 1.25, "/cowboy/Yehaw2.wav"))
        self.SampleSoundGroups["Cowboy Country"]=newSG

        newSG = SoundGroup("Doctor Foster")
        newSG.Sounds.append(Sample(_("Doctor Foster"), 1.02, "/doctor_foster/doctor_foster.wav"))
        newSG.Sounds.append(Sample(_("Went to Gloucester"), 1.16, "/doctor_foster/went_to_gloucester.wav"))
        newSG.Sounds.append(Sample(_("In a shower of rain"), 1.51, "/doctor_foster/in_a_shower_of_rain.wav"))
        newSG.Sounds.append(Sample(_("He stepped in a puddle"), 1.09, "/doctor_foster/he_stepped_in_a_puddle.wav"))
        newSG.Sounds.append(Sample(_("Right up to his middle"), 1.38, "/doctor_foster/right_up_to_his_middle.wav"))
        newSG.Sounds.append(Sample(_("And never went there again"), 1.86, "/doctor_foster/and_never_went_there_again.wav"))
        self.SampleSoundGroups["Doctor Foster"] = newSG

        newSG = SoundGroup("Explosion")
        newSG.Sounds.append(Sample(_("One"), 0.974, "/numbers/1.wav"))
        newSG.Sounds.append(Sample(_("Two"), 0.965, "/numbers/2.wav"))
        newSG.Sounds.append(Sample(_("Three"), 0.972, "/numbers/3.wav"))
        newSG.Sounds.append(Sample(_("Four"), 0.973, "/numbers/4.wav"))
        newSG.Sounds.append(Sample(_("Five"), 0.990, "/numbers/5.wav"))
        newSG.Sounds.append(Sample(_("Glass Break"), 0.62, "/explosion/glass_breaking.wav"))
        newSG.Sounds.append(Sample(_("Explosion"), 6.43, "/explosion/explosion.wav"))
        newSG.Sounds.append(Sample(_("Oh no!"), 1.37, "/explosion/oh_no.wav"))
        self.SampleSoundGroups["Explosion"] = newSG
        
        newSG = SoundGroup("Frère Jacques")
        newSG.Sounds.append(Sample(_("Frère Jacques"), 2.397, "/frere_jacques/frere_jacques.wav"))
        newSG.Sounds.append(Sample(_("Dormez-vous?"), 2.202, "/frere_jacques/dormez_vous.wav"))
        newSG.Sounds.append(Sample(_("Sonnez les matines!"), 2.405, "/frere_jacques/sonnez_les_matines.wav"))
        newSG.Sounds.append(Sample(_("Ding, dang, dong"), 2.237, "/frere_jacques/ding_dang_dong.wav"))
        self.SampleSoundGroups["Frère Jacques"] = newSG

        newSG = SoundGroup("Guitar")
        newSG.Sounds.append(Sample(_("C5"), 0.5, "/guitar/C5.wav"))
        newSG.Sounds.append(Sample(_("D5"), 0.5, "/guitar/D5.wav"))
        newSG.Sounds.append(Sample(_("E5"), 0.5, "/guitar/E5.wav"))
        newSG.Sounds.append(Sample(_("F5"), 0.5, "/guitar/F5.wav"))
        newSG.Sounds.append(Sample(_("G5"), 0.5, "/guitar/G5.wav"))
        newSG.Sounds.append(Sample(_("A5"), 0.5, "/guitar/A5.wav"))
        newSG.Sounds.append(Sample(_("B5"), 0.5, "/guitar/B5.wav"))
        newSG.Sounds.append(Sample(_("C6"), 0.5, "/guitar/C6.wav"))
        self.SampleSoundGroups["Guitar"] = newSG

        newSG = SoundGroup("Helen's Story")
        newSG.Sounds.append(Sample(_("Helen is looking\nfor her friends"), 1.749, "/story/helen_is_looking_for_her_friends.wav"))
        newSG.Sounds.append(Sample(_("She thinks they\nmight be in the"), 1.667, "/story/she_thinks_they_might_be_in_the.wav"))
        newSG.Sounds.append(Sample(_("Cupboard"), 0.463, "/story/cupboard.wav"))
        newSG.Sounds.append(Sample(_("Haunted house"), 1.068, "/story/haunted_house.wav"))
        newSG.Sounds.append(Sample(_("She opens the door"), 1.015, "/story/she_opens_the_door.wav"))
        newSG.Sounds.append(Sample(_("Creaking noise"), 2.733, "/story/creaking_noise.wav"))
        newSG.Sounds.append(Sample(_("Her friends jump\nout and yell surprise!"), 2.684, "/story/her_friends_jump_out_and_yell_surprise.wav"))
        newSG.Sounds.append(Sample(_("She sees a ghost\nand screams"), 2.067, "/story/she_sees_a_ghost_and_screams.wav"))
        self.SampleSoundGroups["Helen's Story"] = newSG

        newSG = SoundGroup("Jingle Bells")
        newSG.Sounds.append(Sample(_("Jingle 1"), 0.78, "/jingle_bells/jingle_1.wav"))
        newSG.Sounds.append(Sample(_("Bells"), 0.79, "/jingle_bells/bells.wav"))
        newSG.Sounds.append(Sample(_("Jingle 2"), 0.77, "/jingle_bells/jingle_2.wav"))
        newSG.Sounds.append(Sample(_("All"), 0.81, "/jingle_bells/all.wav"))
        newSG.Sounds.append(Sample(_("The"), 0.64, "/jingle_bells/the.wav"))
        newSG.Sounds.append(Sample(_("Way"), 0.79, "/jingle_bells/way.wav"))
        self.SampleSoundGroups["Jingle Bells"] = newSG

        newSG = SoundGroup("Make New Friends")
        newSG.Sounds.append(Sample(_("Make new friends\nbut keep the old"), 4.792, "/make_new_friends/make_new_friends.wav"))
        newSG.Sounds.append(Sample(_("One is silver and\nthe other's gold"), 4.756, "/make_new_friends/one_is_silver.wav"))
        newSG.Sounds.append(Sample(_("A circle is round,\nit has no end"), 5.243, "/make_new_friends/a_circle_is_round.wav"))
        newSG.Sounds.append(Sample(_("That’s how long\nI want to be your friend"), 4.96, "/make_new_friends/that_is_how_long.wav"))
        self.SampleSoundGroups["Make New Friends"] = newSG

        newSG = SoundGroup("Nature")
        newSG.Sounds.append(Sample(_("Birds"), 3.13, "/nature/birds.wav"))
        newSG.Sounds.append(Sample(_("Crickets"), 3.27, "/nature/crickets.wav"))
        newSG.Sounds.append(Sample(_("Frogs"), 4.35, "/nature/frogs.wav"))
        newSG.Sounds.append(Sample(_("Thunder"), 3.68, "/nature/thunder.wav"))
        newSG.Sounds.append(Sample(_("Rainfall"), 4.7, "/nature/rainfall.wav"))
        newSG.Sounds.append(Sample(_("Seagulls"), 7.33, "/nature/sea_gulls.wav"))
        newSG.Sounds.append(Sample(_("Splash"), 1.96, "/nature/splash.wav"))
        newSG.Sounds.append(Sample(_("Waves"), 4.63, "/nature/waves.wav"))
        self.SampleSoundGroups["Nature"] = newSG

        newSG = SoundGroup("Numbers")
        newSG.Sounds.append(Sample(_("One"), 0.974, "/numbers/1.wav"))
        newSG.Sounds.append(Sample(_("Two"), 0.965, "/numbers/2.wav"))
        newSG.Sounds.append(Sample(_("Three"), 0.972, "/numbers/3.wav"))
        newSG.Sounds.append(Sample(_("Four"), 0.973, "/numbers/4.wav"))
        newSG.Sounds.append(Sample(_("Five"), 0.990, "/numbers/5.wav"))
        newSG.Sounds.append(Sample(_("Six"), 0.965, "/numbers/6.wav"))
        newSG.Sounds.append(Sample(_("Seven"), 0.973, "/numbers/7.wav"))
        newSG.Sounds.append(Sample(_("Eight"), 0.987, "/numbers/8.wav"))
        self.SampleSoundGroups["Numbers"] = newSG

        newSG = SoundGroup("Numbers in French")
        newSG.Sounds.append(Sample(_("Un"), 0.659, "/numbers_in_french/1.wav"))
        newSG.Sounds.append(Sample(_("Deux"), 0.736, "/numbers_in_french/2.wav"))
        newSG.Sounds.append(Sample(_("Trois"), 0.730, "/numbers_in_french/3.wav"))
        newSG.Sounds.append(Sample(_("Quatre"), 0.671, "/numbers_in_french/4.wav"))
        newSG.Sounds.append(Sample(_("Cinq"), 0.744, "/numbers_in_french/5.wav"))
        newSG.Sounds.append(Sample(_("Six"), 0.746, "/numbers_in_french/6.wav"))
        newSG.Sounds.append(Sample(_("Sept"), 0.710, "/numbers_in_french/7.wav"))
        newSG.Sounds.append(Sample(_("Huit"), 0.727, "/numbers_in_french/8.wav"))
        self.SampleSoundGroups["Numbers in French"] = newSG

        newSG = SoundGroup("People Sounds")
        newSG.Sounds.append(Sample(_("Blowing nose"), 1.05, "/people_sounds/blowing_nose.wav"))
        newSG.Sounds.append(Sample(_("Cheer"), 4.58, "/people_sounds/cheer.wav"))
        newSG.Sounds.append(Sample(_("Ghost"), 3.78, "/people_sounds/ghost.wav"))
        newSG.Sounds.append(Sample(_("Scream"), 1.33, "/people_sounds/Helen_scream.wav"))
        newSG.Sounds.append(Sample(_("Laughing"), 0.89, "/people_sounds/laughing.wav"))
        newSG.Sounds.append(Sample(_("Ohh"), 1.7, "/people_sounds/ohh.wav"))
        newSG.Sounds.append(Sample(_("Sneeze"), 0.86, "/people_sounds/sneeze.wav"))
        newSG.Sounds.append(Sample(_("Surprise!"), 2.11, "/people_sounds/surprise.wav"))
        self.SampleSoundGroups["People Sounds"] = newSG

        newSG = SoundGroup("Percussion")
        newSG.Sounds.append(Sample(_("Bass drum"), 0.47, "/percussion/bass_drum.wav"))
        newSG.Sounds.append(Sample(_("Conga drum"), 0.33, "/percussion/conga_drum.wav"))
        newSG.Sounds.append(Sample(_("Cowbell"), 0.37, "/percussion/cowbell.wav"))
        newSG.Sounds.append(Sample(_("Cymbal crash"), 0.96, "/percussion/cymbal_crash.wav"))
        newSG.Sounds.append(Sample(_("Djembe drum"), 0.46, "/percussion/djembe_drum.wav"))
        newSG.Sounds.append(Sample(_("Hi-Hat 1"), 0.57, "/percussion/hi_hat_1.wav"))
        newSG.Sounds.append(Sample(_("Hi-Hat 2"), 0.35, "/percussion/hi_hat_2.wav"))
        newSG.Sounds.append(Sample(_("Snare drum"), 0.44, "/percussion/snare_drum.wav"))
        self.SampleSoundGroups["Percussion"] = newSG

        newSG = SoundGroup("Poem")
        newSG.Sounds.append(Sample(_("Mashed potatoes"), 1.11, "/poem/mashed_potatoes.wav"))
        newSG.Sounds.append(Sample(_("On the ceiling"), 0.93, "/poem/on_the_ceiling.wav"))
        newSG.Sounds.append(Sample(_("Green beans"), 1.2, "/poem/green_beans.wav"))
        newSG.Sounds.append(Sample(_("On the floor"), 0.89, "/poem/on_the_floor.wav"))
        newSG.Sounds.append(Sample(_("Stewed tomatoes"), 1.37, "/poem/stewed_tomatoes.wav"))
        newSG.Sounds.append(Sample(_("In the corner"), 0.87, "/poem/in_the_corner.wav"))
        newSG.Sounds.append(Sample(_("Squash"), 0.83, "/poem/squash.wav"))
        newSG.Sounds.append(Sample(_("Upon the door"), 0.95, "/poem/upon_the_door.wav"))
        self.SampleSoundGroups["Poem"] = newSG

        newSG = SoundGroup("Row Your Boat")
        newSG.Sounds.append(Sample(_("Row"), 0.82, "/row_your_boat/row.wav"))
        newSG.Sounds.append(Sample(_("Your boat"), 0.82, "/row_your_boat/your_boat.wav"))
        newSG.Sounds.append(Sample(_("Gently down the stream"), 0.82, "/row_your_boat/gently_down_the_stream.wav"))
        newSG.Sounds.append(Sample(_("Merrily 1"), 0.95, "/row_your_boat/merrily_1.wav"))
        newSG.Sounds.append(Sample(_("Merrily 2"), 0.88, "/row_your_boat/merrily_2.wav"))
        newSG.Sounds.append(Sample(_("Merrily 3"), 0.83, "/row_your_boat/merrily_3.wav"))
        newSG.Sounds.append(Sample(_("Merrily 4"), 0.82, "/row_your_boat/merrily_4.wav"))
        newSG.Sounds.append(Sample(_("Life is but a dream"), 2.26, "/row_your_boat/life_is_but_a_dream.wav"))
        self.SampleSoundGroups["Row Your Boat"] = newSG

        newSG = SoundGroup("Sirens and Vehicles")
        newSG.Sounds.append(Sample(_("Alarm"), 2.91, "/sirens_and_vehicles/alarm.wav"))
        newSG.Sounds.append(Sample(_("Ambulance"), 7.47, "/sirens_and_vehicles/ambulance.wav"))
        newSG.Sounds.append(Sample(_("Car horn"), 0.84, "/sirens_and_vehicles/car_horn.wav"))
        newSG.Sounds.append(Sample(_("Car speeding away"), 11.01, "/sirens_and_vehicles/car_speeding_away.wav"))
        newSG.Sounds.append(Sample(_("Car starting"), 9.13, "/sirens_and_vehicles/car_starting.wav"))
        newSG.Sounds.append(Sample(_("Fire truck"), 12.87, "/sirens_and_vehicles/fire_truck.wav"))
        newSG.Sounds.append(Sample(_("Motorcycle"), 5.38, "/sirens_and_vehicles/motorcycle.wav"))
        newSG.Sounds.append(Sample(_("Police siren"), 4.46, "/sirens_and_vehicles/police_siren.wav"))
        self.SampleSoundGroups["Sirens and Vehicles"] = newSG

        newSG = SoundGroup("Tools")
        newSG.Sounds.append(Sample(_("Chainsaw"), 9.82, "/tools/chainsaw.wav"))
        newSG.Sounds.append(Sample(_("Clanking"), 2.40, "/tools/clanking.wav"))
        newSG.Sounds.append(Sample(_("Clock ticking"), 5.06, "/tools/clock_ticking.wav"))
        newSG.Sounds.append(Sample(_("Drill gun"), 2.12, "/tools/drill_gun.wav"))
        newSG.Sounds.append(Sample(_("Hammer"), 1.57, "/tools/hammer.wav"))
        newSG.Sounds.append(Sample(_("Jackhammer"), 4.0, "/tools/jackhammer.wav"))
        newSG.Sounds.append(Sample(_("Sawing metal"), 5.21, "/tools/sawing_metal.wav"))
        newSG.Sounds.append(Sample(_("Sawing wood"), 5.93, "/tools/sawing_wood.wav"))
        self.SampleSoundGroups["Tools"] = newSG

        newSG = SoundGroup("Twinkle, Twinkle")
        newSG.Sounds.append(Sample(_("Twinkle 1"), 1.03, "/twinkle_twinkle/twinkle_1.wav"))
        newSG.Sounds.append(Sample(_("Twinkle 2"), 1.07, "/twinkle_twinkle/twinkle_2.wav"))
        newSG.Sounds.append(Sample(_("Little"), 1.14, "/twinkle_twinkle/little.wav"))
        newSG.Sounds.append(Sample(_("Star"), 1, "/twinkle_twinkle/star.wav"))
        self.SampleSoundGroups["Twinkle, Twinkle"] = newSG

    def InitializePuzzlesSoundGroups(self):
        newSG = SoundGroup("Spacewalk")
        newSG.Sounds.append(Sample(_("1"), 19.20, "/spacewalk/1.wav"))
        newSG.Sounds.append(Sample(_("2"), 2.02, "/spacewalk/2.wav"))
        newSG.Sounds.append(Sample(_("3"), 14.48, "/spacewalk/3.wav"))
        newSG.Sounds.append(Sample(_("4"), 15, "/spacewalk/4.wav"))
        newSG.Sounds.append(Sample(_("5"), 2.06, "/spacewalk/5.wav"))
        newSG.Sounds.append(Sample(_("6"), 15.38, "/spacewalk/6.wav"))
        newSG.Sounds.append(Sample(_("7"), 17.95, "/spacewalk/7.wav"))
        newSG.Sounds.append(Sample(_("8"), 16.78, "/spacewalk/8.wav"))
        self.SampleSoundGroups["Spacewalk"] = newSG

        newSG = SoundGroup("Pizza")
        newSG.Sounds.append(Sample(_("Gummy Worms"), 0.54, "/pizza/gummy-worms.wav"))
        newSG.Sounds.append(Sample(_("Mozarella Cheese"), 1.86, "/pizza/mozzarella-cheese.wav"))
        newSG.Sounds.append(Sample(_("Olives"), 0.94, "/pizza/olives.wav"))
        newSG.Sounds.append(Sample(_("Pineapple"), 1.8, "/pizza/pineapple.wav"))
        newSG.Sounds.append(Sample(_("Pizza Sauce"), 0.37, "/pizza/pizza-sauce.wav"))
        newSG.Sounds.append(Sample(_("Potato Chips"), 0.82, "/pizza/potato-chips.wav"))
        newSG.Sounds.append(Sample(_("Sprinkles"), 1.0, "/pizza/sprinkles.wav"))
        newSG.Sounds.append(Sample(_("Whipped Cream"), 1.46, "/pizza/whipped-cream.wav"))
        self.SampleSoundGroups["Pizza"] = newSG

        newSG = SoundGroup("Water Cycle")
        newSG.Sounds.append(Sample(_("Cloud"), 7.5, "/water_cycle/4-cloud.wav"))
        newSG.Sounds.append(Sample(_("Liquid"), 5.0, "/water_cycle/5-liquid.wav"))
        newSG.Sounds.append(Sample(_("Ocean"), 12.0, "/water_cycle/6-ocean.wav"))
        newSG.Sounds.append(Sample(_("River"), 10.0, "/water_cycle/7-river.wav"))
        newSG.Sounds.append(Sample(_("Sun"), 10.0, "/water_cycle/8-sun.wav"))
        newSG.Sounds.append(Sample(_("Steam"), 9.5, "/water_cycle/10-steam.wav"))
        newSG.Sounds.append(Sample(_("Rain"), 7.0, "/water_cycle/12-rain.wav"))
        newSG.Sounds.append(Sample(_("Glacier"), 5.84, "/water_cycle/15-glacier.wav"))
        self.SampleSoundGroups["Water Cycle"] = newSG

        newSG = SoundGroup("Water States")
        newSG.Sounds.append(Sample(_("Gas"), 9.5, "/water_states/gas.wav"))
        newSG.Sounds.append(Sample(_("Solid"), 5.0, "/water_states/solid.wav"))
        newSG.Sounds.append(Sample(_("Liquid"), 8.82, "/water_states/liquid.wav"))
        self.SampleSoundGroups["Water States"] = newSG

        newSG = SoundGroup("Mystery Rhyme")
        newSG.Sounds.append(Sample(_("Chimes"), 14.0, "/mystery_rhyme/chimes.wav"))
        newSG.Sounds.append(Sample(_("Letter-H"), 2.0, "/mystery_rhyme/letter-h.wav"))
        newSG.Sounds.append(Sample(_("Leter-O"), 2.0, "/mystery_rhyme/letter-o.wav"))
        newSG.Sounds.append(Sample(_("Letter-T"), 3.0, "/mystery_rhyme/letter-t.wav"))
        newSG.Sounds.append(Sample(_("Letter-D"), 3.0, "/mystery_rhyme/letter-d.wav"))
        newSG.Sounds.append(Sample(_("Letter--O"), 3.0, "/mystery_rhyme/letter--o.wav"))
        newSG.Sounds.append(Sample(_("Letter-G"), 3.0, "/mystery_rhyme/letter-g.wav"))
        self.SampleSoundGroups["Mystery Rhyme"] = newSG

        newSG = SoundGroup("Treasure Hunt")
        newSG.Sounds.append(Sample(_("1"), 1.0, "/treasure_hunt/1.wav"))
        newSG.Sounds.append(Sample(_("2"), 1.0, "/treasure_hunt/2.wav"))
        newSG.Sounds.append(Sample(_("3"), 1.0, "/treasure_hunt/3.wav"))
        newSG.Sounds.append(Sample(_("4"), 1.0, "/treasure_hunt/4.wav"))
        newSG.Sounds.append(Sample(_("5"), 1.0, "/treasure_hunt/5.wav"))
        newSG.Sounds.append(Sample(_("6"), 1.0, "/treasure_hunt/6.wav"))
        newSG.Sounds.append(Sample(_("7"), 1.0, "/treasure_hunt/7.wav"))
        newSG.Sounds.append(Sample(_("8"), 1.0, "/treasure_hunt/8.wav"))
        self.SampleSoundGroups["Treasure Hunt"] = newSG

        newSG = SoundGroup("Launch")
        newSG.Sounds.append(Sample(_("1"), 1.0, "/launch/1.wav"))
        newSG.Sounds.append(Sample(_("2"), 1.0, "/launch/2.wav"))
        newSG.Sounds.append(Sample(_("3"), 1.0, "/launch/3.wav"))
        newSG.Sounds.append(Sample(_("Buckle Up"), 0.94, "/launch/buckle-up.wav"))
        newSG.Sounds.append(Sample(_("Cheers"), 18.0, "/launch/cheers.wav"))
        newSG.Sounds.append(Sample(_("Ignition"), 8.0, "/launch/ignition.wav"))
        newSG.Sounds.append(Sample(_("Lift Off"), 10.0, "/launch/lift-off.wav"))
        newSG.Sounds.append(Sample(_("Slamming Door"), 1.0, "/launch/slamming-door.wav"))
        self.SampleSoundGroups["Launch"] = newSG

        newSG = SoundGroup("Preflight Check")
        newSG.Sounds.append(Sample(_("Drill"), 2.31, "/preflight_check/drill.wav"))
        newSG.Sounds.append(Sample(_("Hammer"), 0.27, "/preflight_check/hammer.wav"))
        newSG.Sounds.append(Sample(_("Oil Guggling"), 1.84, "/preflight_check/oil-guggling.wav"))
        newSG.Sounds.append(Sample(_("Saw"), 6.67, "/preflight_check/saw.wav"))
        newSG.Sounds.append(Sample(_("Screwdriver"), 2.97, "/preflight_check/screwdriver.wav"))
        newSG.Sounds.append(Sample(_("Spring"), 2.30, "/preflight_check/spring.wav"))
        self.SampleSoundGroups["Preflight Check"] = newSG

        newSG = SoundGroup("Souvenirs")
        newSG.Sounds.append(Sample(_("Rooster"), 3.01, "/souvenirs/1-rooster.wav"))
        newSG.Sounds.append(Sample(_("Horse"), 3.0, "/souvenirs/2-horse.wav"))
        newSG.Sounds.append(Sample(_("Piano"), 15.0, "/souvenirs/3-piano.wav"))
        newSG.Sounds.append(Sample(_("Bouncing Ball"), 9.28, "/souvenirs/4-bouncing-ball.wav"))
        newSG.Sounds.append(Sample(_("Fire Truck"), 12.02, "/souvenirs/5-fire-truck.wav"))
        newSG.Sounds.append(Sample(_("Crowd of People"), 10.04, "/souvenirs/6-crowd-of-people.wav"))
        newSG.Sounds.append(Sample(_("Cash Registers"), 3.68, "/souvenirs/7-cash-register.wav"))
        newSG.Sounds.append(Sample(_("Fizzy Drink Opening"), 10.29, "/souvenirs/8-fizzy-drink-opening.wav"))
        self.SampleSoundGroups["Souvenirs"] = newSG

        newSG = SoundGroup("Amusement Park")
        newSG.Sounds.append(Sample(_("Roller Coaster"), 10.0, "/amusement_park/1-roller-coaster.wav"))
        newSG.Sounds.append(Sample(_("Carousel"), 15.0, "/amusement_park/2-carousel.wav"))
        newSG.Sounds.append(Sample(_("French Fries"), 15.0, "/amusement_park/3-french-fries.wav"))
        newSG.Sounds.append(Sample(_("Popcorn"), 15.0, "/amusement_park/4-popcorn.wav"))
        newSG.Sounds.append(Sample(_("How Strong Are You"), 1.44, "/amusement_park/5-how-strong-are-you.wav"))
        newSG.Sounds.append(Sample(_("Skee Ball"), 15.06, "/amusement_park/6-skee-ball.wav"))
        newSG.Sounds.append(Sample(_("A Talking Parrot"), 1.11, "/amusement_park/7-a-talking-parrot.wav"))
        newSG.Sounds.append(Sample(_("A Pet Fish"), 3.0, "/amusement_park/8-a-pet-fish.wav"))
        self.SampleSoundGroups["Amusement Park"] = newSG

        newSG = SoundGroup("Where does CJ go next?")
        newSG.Sounds.append(Sample(_("International Space Station"), 7.07, "/where_does_cj_go_next/international-space-station.wav"))
        newSG.Sounds.append(Sample(_("Mars Distance"), 5.68, "/where_does_cj_go_next/mars-distance.wav"))
        newSG.Sounds.append(Sample(_("People on Mars"), 5.63, "/where_does_cj_go_next/people-on-mars.wav"))
        newSG.Sounds.append(Sample(_("People on the ISS"), 3.34, "/where_does_cj_go_next/people-on-the-ISS.wav"))
        newSG.Sounds.append(Sample(_("Sunrise and Sunset ISS"), 5.01, "/where_does_cj_go_next/sunrise-and-sunset-ISS.wav"))
        newSG.Sounds.append(Sample(_("Sunrise and Sunset Mars"), 5.51, "/where_does_cj_go_next/sunrise-and-sunset-mars.wav"))
        newSG.Sounds.append(Sample(_("Temperature on Mars"), 4.68, "/where_does_cj_go_next/temperature-on-mars.wav"))
        newSG.Sounds.append(Sample(_("Temperature on the ISS"), 8.58, "/where_does_cj_go_next/temperature-on-the-ISS.wav"))
        self.SampleSoundGroups["Where does CJ go next?"] = newSG



