import wave
import time
import pyaudio
import constant
from sample import Sample

class SoundPlayer:
    def __init__(self):
        self.chunk = 256
        self.p = pyaudio.PyAudio()
        self.pauseSleep = [0.250, 0.500, 1.000, 2.000]
        self.pauseString = ["Quarter Beat", "Half Beat", "One Beat", "Two Beat"]
        # Number of frames to play for 0.5, 1, 1.5, and 2 seconds 
        self.midiSize = [22050, 44100, 66150, 88200]

    def Play(self, sounds, index, dModifier):
        #self.PlaySample(sounds, index, dModifier)
        #return
        if (isinstance(sounds.Sounds[0], Sample)):
            self.PlaySample(sounds, index, dModifier)
        else:
            self.PlayMidi(sounds, index, dModifier)

    def PlaySample(self, sounds, index, dModifier):
        sound = sounds.Sounds[(index-1) % len(sounds.Sounds)]
        print("Play Sound: "+ sound.Name)

        durationModifier = constant.DurationMultipliers[(dModifier-1) % 4]

        wf = wave.open(self.Location + sound.FilePath, 'rb')

        playbackRate = int(wf.getframerate() * durationModifier)

        stream = self.p.open(format = self.p.get_format_from_width(wf.getsampwidth()),
                        channels = wf.getnchannels(),
                        rate=playbackRate,
                        output=True)

        # read data (based on the chunk size)
        data = wf.readframes(self.chunk)
        # play stream (looping form beginning to end)
        while len(data) > 0:
            # writing to the stream is what *actually* plays the sound.
            stream.write(data)
            data = wf.readframes(self.chunk)

        # cleanup stuff
        stream.close()

    def Pause(self, duration):
        print("Pause: " + self.pauseString[(duration-1) % 4]);
        time.sleep(self.pauseSleep[(duration-1) % 4]);

    def SetSoundFolderLocation(self, location):
        self.Location = location

    def Finished(self):
        self.p.terminate()

    def PlayMidi(self, sounds, index, dModifier):
        sound = sounds.Sounds[(index-1) % len(sounds.Sounds)]
        print("Play Sound: "+ sound.Name)
        
        durationModifier = (dModifier-1) % 4

        wf = wave.open(self.Location + sound.FilePath, 'rb')

        #playbackRate = int(wf.getframerate() * durationModifier)
        playbackRate = int(wf.getframerate() * 1.0)

        stream = self.p.open(format = self.p.get_format_from_width(wf.getsampwidth()),
                        channels = wf.getnchannels(),
                        rate=playbackRate,
                        output=True)

        print(self.midiSize[durationModifier])
        # read data (based on the midi duration)
        data = wf.readframes(self.chunk)
        totalBytes = 0

        # play if data is available
        while ((len(data) > 0) and (totalBytes<self.midiSize[durationModifier])):
            # writing to the stream is what *actually* plays the sound.
            stream.write(data)
            totalBytes += self.chunk
            #if (totalBytes >= self.midiSize[duraitonModifier]):
            #    break
            if (totalBytes+self.chunk>self.midiSize[durationModifier]):
                data = wf.readframes(self.midiSize[durationModifier]-totalBytes)
            data = wf.readframes(self.chunk)

        # cleanup stuff
        stream.close()

